#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.16
visibility:           public
id:                   gitit-0.16-5tTX5FPqswqAk1w87jjPAY
key:                  gitit-0.16-5tTX5FPqswqAk1w87jjPAY
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  53aa51d9a8092b72e722ef711399817e
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Server Network.Gitit.State Network.Gitit.Types
    Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.16-5tTX5FPqswqAk1w87jjPAY
depends:
    HStringTemplate-0.8.8-Aa33oNQKeIF5bny0izcr2t
    HTTP-4000.5.0-KBzZkhcIDg0EA6RYEQDu68
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-CuqyF0GV84l91XsdnO7HOm base-4.18.2.1
    base64-bytestring-1.2.1.0-6ahp7SfFZkd6mBBNURIRpE
    blaze-html-0.9.2.0-2ifJy4x0Ofgnm9DsNHg6P bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-1oOyrQA1yAE1OQm4lAVYQS
    feed-1.3.2.1-9K4T3r5GVp3CyxSucMH3CI filepath-1.4.300.1
    filestore-0.6.5.1-zuCf04jBEFHA0OaDnlZr7 ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-B0BuX1cjTD4AMyWwm2vrbS
    hoauth2-2.14.0-CO6XoAViGbS8I056HTgXoi
    hslogger-1.3.2.0-60j7EiJxRXYDf7TfbUgGDp
    http-client-tls-0.3.6.4-IKN6IcefmTuChedx1hJelo
    http-conduit-2.3.9.1-7PV9PoY806LKEidsz6qgxy
    json-0.11-7LLsGbu0XsB1k3BUZ1woHQ mtl-2.3.1
    network-3.1.4.0-Lt0aE8CPrcjIQCbzsjcySE
    network-bsd-2.8.1.0-Bn6rdsGi0IOGAn1ln05EZ9
    network-uri-2.6.4.2-JQnyVhRAD0FHP2QsmDrZ2X
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.1.0-7ixfHOnC0EQ4MB4fd6au4h
    pandoc-3.6-D1cCl1w21aPHPbX09dwKu4
    pandoc-types-1.23.1.1-8ps1keK6oVbLtSoc8QFKWD parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-Lghf55MzNhHBpx4j4jRaDh
    recaptcha-0.1.0.4-INy1U8hlTs1F5Yc6wywFzb
    safe-0.3.21-2iv11P1GTSG3w8ujmSn6bG
    skylighting-0.14.4-ELhpuN7FtogAMOVFjDGC4p
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-9ztCG0Q7snPDhcPoUMdZvi
    tagsoup-0.14.8-GEAXIHXlRWQIgbMJDOEHQb
    temporary-1.3-LTX3u1vohXk4GrYIUDSDQU text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-82bxR1DTWyZCIJ6pjdymzi
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16.1-KbjYJrvd1YaAyXdG6YrOlI xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-GDY7DDNPloU6K4zQAZQxw9
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-1BR90eSMf0k3HN272asrUI
    zlib-0.7.1.0-8qXCIKzauXr8hw72sCn5cF

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

